@@ -40,6 +40,7 @@ from .exceptions import RoborockException, RoborockTimeout, VacuumError
 from .roborock_future import RoborockFuture
 from .roborock_message import RoborockMessage
 from .typing import RoborockCommand, RoborockDeviceProp, RoborockDockSummary
+from .util import unpack_list
 
 _LOGGER = logging.getLogger(__name__)
 QUEUE_TIMEOUT = 4
@@ -190,6 +191,14 @@ class RoborockClient:
             clean_summary = await self.send_command(device_id, RoborockCommand.GET_CLEAN_SUMMARY)
             if isinstance(clean_summary, dict):
                 return CleanSummary.from_dict(clean_summary)
+            elif isinstance(clean_summary, list):
+                clean_time, clean_area, clean_count, records = unpack_list(clean_summary, 4)
+                return CleanSummary(
+                    clean_time=clean_time,
+                    clean_area=clean_area,
+                    clean_count=clean_count,
+                    records=records
+                )
             elif isinstance(clean_summary, int):
                 return CleanSummary(clean_time=clean_summary)
         except RoborockTimeout as e:
@@ -244,6 +253,7 @@ class RoborockClient:
     async def get_dock_summary(self, device_id: str, dock_type: RoborockEnum) -> RoborockDockSummary | None:
         """Gets the status summary from the dock with the methods available for a given dock.
 
+        :param device_id: Device id
         :param dock_type: RoborockDockTypeCode"""
         try:
             commands: list[
@@ -258,9 +268,7 @@ class RoborockClient:
                     self.get_wash_towel_mode(device_id),
                     self.get_smart_wash_params(device_id),
                 ]
-            [dust_collection_mode, wash_towel_mode, smart_wash_params] = (
-                list(await asyncio.gather(*commands)) + [None, None]
-            )[:3]
+            [dust_collection_mode, wash_towel_mode, smart_wash_params] = unpack_list(list(await asyncio.gather(*commands)), 3)
 
             return RoborockDockSummary(dust_collection_mode, wash_towel_mode, smart_wash_params)
         except RoborockTimeout as e:
@@ -280,7 +288,7 @@ class RoborockClient:
         if clean_summary and clean_summary.records and len(clean_summary.records) > 0:
             last_clean_record = await self.get_clean_record(device_id, clean_summary.records[0])
         dock_summary = None
-        if status and status.dock_type != RoborockDockTypeCode["0"]:
+        if status and status.dock_type is not None and status.dock_type != RoborockDockTypeCode["0"]:
             dock_summary = await self.get_dock_summary(device_id, status.dock_type)
         if any([status, dnd_timer, clean_summary, consumable]):
             return RoborockDeviceProp(
